@@ -7,9 +7,9 @@
 #ifndef SETTINGS_BASE_H
 #define SETTINGS_BASE_H
 
-#include "BaseMode.h"
 #include "MenuItem.h"
-#include "tooltipmanager.h"
+#include "SidebarMode.h"
+
 #include <QButtonGroup>
 #include <QMap>
 #include <QStackedWidget>
@@ -18,16 +18,17 @@
 #include <KActionMenu>
 #include <KConfigDialog>
 #include <KLineEdit>
-#include <KXmlGuiWindow>
+#include <KMainWindow>
 
 class QScreen;
+class KHelpMenu;
 
-class SettingsBase : public KXmlGuiWindow
+class SettingsBase : public KMainWindow
 {
     Q_OBJECT
 
 public:
-    explicit SettingsBase(BaseMode::ApplicationMode mode, const QString &startupModule, const QStringList &startupModuleArgs, QWidget *parent = nullptr);
+    explicit SettingsBase(SidebarMode::ApplicationMode mode, const QString &startupModule, const QStringList &startupModuleArgs, QWidget *parent = nullptr);
     ~SettingsBase() override;
     bool queryClose() override;
 
@@ -41,12 +42,9 @@ protected:
 private Q_SLOTS:
     void initApplication();
     void initToolBar();
-    void initHelpMenu();
     void initMenuList(MenuItem *parent);
     void about();
     void viewChange(bool state);
-    void updateViewActions();
-    void changeToolBar(BaseMode::ToolBarItems toolbar);
 
 private Q_SLOTS:
     /**
@@ -64,10 +62,7 @@ private:
     QScreen *m_screen = nullptr;
 
     // The plugins
-    QList<ToolTipManager *> tooltipManagers;
-    BaseMode *view = nullptr;
-    // The search bar
-    QWidget *spacerWidget = nullptr;
+    SidebarMode *view = nullptr;
     // The toolbar
     QWidgetAction *spacerAction = nullptr;
     QAction *highlightChangesAction = nullptr;
@@ -86,8 +81,10 @@ private:
     QList<KPluginMetaData> pluginModules;
     // The about dialog
     KAboutApplicationDialog *aboutDialog = nullptr;
-    BaseMode::ApplicationMode m_mode = BaseMode::SystemSettings;
+    SidebarMode::ApplicationMode m_mode = SidebarMode::SystemSettings;
     QString m_startupModule;
     QStringList m_startupModuleArgs;
+    KActionCollection *m_actionCollection;
+    KHelpMenu *m_helpMenu;
 };
 #endif
